@@ -14,41 +14,17 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import os
+import sys
+
 import fixtures
 import mock
-import six
-import os
-import tempfile
 import testtools
 
-from bandit.core import manager
 from bandit.core import config
-from bandit.core import issue
 from bandit.core import constants
-from bandit.core import extension_loader
-
-from sys import version_info
-if version_info.major == 2:
-    import __builtin__ as builtins
-else:
-    import builtins
-
-
-class TempFile(fixtures.Fixture):
-    def __init__(self, contents=None):
-        super(TempFile, self).__init__()
-        self.contents = contents
-
-    def setUp(self):
-        super(TempFile, self).setUp()
-
-        with tempfile.NamedTemporaryFile(mode='wt', delete=False) as f:
-            if self.contents:
-                f.write(self.contents)
-
-        self.addCleanup(os.unlink, f.name)
-
-        self.name = f.name
+from bandit.core import issue
+from bandit.core import manager
 
 
 class ManagerTests(testtools.TestCase):
@@ -62,50 +38,32 @@ class ManagerTests(testtools.TestCase):
 
     def setUp(self):
         super(ManagerTests, self).setUp()
-        contents = """
-            profiles:
-                Test:
-                    include:
-                        - any_other_function_with_shell_equals_true
-                        - assert_used
-        """
-        f = self.useFixture(TempFile(contents))
-        self.config = config.BanditConfig(f.name)
+        self.profile = {}
+        self.profile['include'] = {
+            'any_other_function_with_shell_equals_true',
+            'assert_used'}
+
+        self.config = config.BanditConfig()
         self.manager = manager.BanditManager(config=self.config,
                                              agg_type='file',
                                              debug=False,
-                                             verbose=False,
-                                             profile_name=None)
+                                             verbose=False)
 
     def test_create_manager(self):
         # make sure we can create a manager
         self.assertEqual(self.manager.debug, False)
         self.assertEqual(self.manager.verbose, False)
         self.assertEqual(self.manager.agg_type, 'file')
-        self.assertTrue(self.manager.has_tests)
 
     def test_create_manager_with_profile(self):
         # make sure we can create a manager
         m = manager.BanditManager(config=self.config, agg_type='file',
                                   debug=False, verbose=False,
-                                  profile_name='Test')
+                                  profile=self.profile)
 
         self.assertEqual(m.debug, False)
         self.assertEqual(m.verbose, False)
         self.assertEqual(m.agg_type, 'file')
-        self.assertTrue(self.manager.has_tests)
-
-
-    def test_create_manager_with_profile_bad(self):
-        try:
-            m = manager.BanditManager(config=self.config, agg_type='file',
-                                      debug=False, verbose=False,
-                                      profile_name='Bad')
-        except RuntimeError as e:
-            err = str(e)
-
-        self.assertTrue(err.startswith(
-            "unable to find profile (Bad) in config file:"))
 
     def test_matches_globlist(self):
         self.assertTrue(manager._matches_glob_list('test', ['*tes*']))
@@ -132,7 +90,6 @@ class ManagerTests(testtools.TestCase):
         self.assertFalse(c)
         self.assertFalse(d)
 
-
     @mock.patch('os.walk')
     def test_get_files_from_dir(self, os_walk):
         os_walk.return_value = [
@@ -147,48 +104,78 @@ class ManagerTests(testtools.TestCase):
         self.assertEqual(exc, set(['/a/c.ww']))
         self.assertEqual(inc, set(['/a/a.py', '/a/b.py']))
 
+    def test_populate_baseline_success(self):
+        # Test populate_baseline with valid JSON
+        baseline_data = """{
+            "results": [
+                {
+                    "code": "test code",
+                    "filename": "example_file.py",
+                    "issue_severity": "low",
+                    "issue_confidence": "low",
+                    "issue_text": "test issue",
+                    "test_name": "some_test",
+                    "test_id": "x",
+                    "line_number": "n",
+                    "line_range": "n-m"
+                }
+            ]
+        }
+        """
+        issue_dictionary = {"code": "test code", "filename": "example_file.py",
+                            "issue_severity": "low", "issue_confidence": "low",
+                            "issue_text": "test issue", "test_name":
+                            "some_test", "test_id": "x", "line_number": "n",
+                            "line_range": "n-m"}
+        baseline_items = [issue.issue_from_dict(issue_dictionary)]
+        self.manager.populate_baseline(baseline_data)
+        self.assertEqual(baseline_items, self.manager.baseline)
+
+    @mock.patch('logging.Logger.warning')
+    def test_populate_baseline_invalid_json(self, mock_logger_warning):
+        # Test populate_baseline with invalid JSON content
+        baseline_data = """{"data": "bad"}"""
+        self.manager.populate_baseline(baseline_data)
+        # Default value for manager.baseline is []
+        self.assertEqual([], self.manager.baseline)
+        self.assertTrue(mock_logger_warning.called)
+
     def test_results_count(self):
         levels = [constants.LOW, constants.MEDIUM, constants.HIGH]
         self.manager.results = (
             [issue.Issue(severity=l, confidence=l) for l in levels])
 
-        r = [self.manager.results_count(sev_filter=l, conf_filter=l) \
-                for l in levels]
+        r = [self.manager.results_count(sev_filter=l, conf_filter=l)
+             for l in levels]
 
-        self.assertEqual([3,2,1], r)
+        self.assertEqual([3, 2, 1], r)
 
-    @mock.patch('os.path.isfile')
-    def test_check_output_destination_exists(self, isfile):
-        isfile.return_value = True
-        a = self.manager.check_output_destination('derp')
-        self.assertEqual(a, 'File already exists')
+    def test_output_results_invalid_format(self):
+        # Test that output_results succeeds given an invalid format
+        temp_directory = self.useFixture(fixtures.TempDir()).path
+        lines = 5
+        sev_level = constants.LOW
+        conf_level = constants.LOW
+        output_filename = os.path.join(temp_directory, "_temp_output")
+        output_format = "invalid"
+        self.manager.output_results(lines, sev_level, conf_level,
+                                    output_filename, output_format)
+        if sys.stdout.isatty():
+            self.assertFalse(os.path.isfile(output_filename))
+        else:
+            self.assertTrue(os.path.isfile(output_filename))
 
-    @mock.patch('os.path.isfile')
-    @mock.patch('os.path.isdir')
-    def test_check_output_destination_dir(self, isdir, isfile):
-        isfile.return_value = False
-        isdir.return_value = True
-        a = self.manager.check_output_destination('derp')
-        self.assertEqual(a, 'Specified destination is a directory')
-
-    @mock.patch('os.path.isfile')
-    @mock.patch('os.path.isdir')
-    def test_check_output_destination_bad(self, isfile, isdir):
-        with mock.patch.object(builtins, 'open') as b_open:
-            isfile.return_value = False
-            isdir.return_value = False
-            b_open.side_effect = IOError()
-            a = self.manager.check_output_destination('derp')
-            self.assertEqual(a, 'Specified destination is not writable')
-
-    @mock.patch('os.path.isfile')
-    @mock.patch('os.path.isdir')
-    def test_check_output_destination_bad(self, isfile, isdir):
-        with mock.patch.object(builtins, 'open'):
-            isfile.return_value = False
-            isdir.return_value = False
-            a = self.manager.check_output_destination('derp')
-            self.assertEqual(a, True)
+    def test_output_results_valid_format(self):
+        # Test that output_results succeeds given a valid format
+        temp_directory = self.useFixture(fixtures.TempDir()).path
+        lines = 5
+        sev_level = constants.LOW
+        conf_level = constants.LOW
+        output_filename = os.path.join(temp_directory, "_temp_output.txt")
+        output_format = "txt"
+        self.manager.output_results(lines, sev_level, conf_level,
+                                    output_filename, output_format)
+        self.assertTrue(os.path.isfile(output_filename))
 
     @mock.patch('os.path.isdir')
     def test_discover_files_recurse_skip(self, isdir):
@@ -221,7 +208,8 @@ class ManagerTests(testtools.TestCase):
         with mock.patch.object(manager, '_is_file_included') as m:
             self.manager.discover_files(['a', 'b', 'c'], True,
                                         excluded_paths='a,b')
-            m.assert_called_with('c', ['*.py'], ['a', 'b'], enforce_glob=False)
+            m.assert_called_with('c', ['*.py', '*.pyw'], ['a', 'b'],
+                                 enforce_glob=False)
 
     @mock.patch('os.path.isdir')
     def test_discover_files_include(self, isdir):
@@ -232,52 +220,30 @@ class ManagerTests(testtools.TestCase):
             self.assertEqual(self.manager.files_list, ['thing'])
             self.assertEqual(self.manager.excluded_files, [])
 
-    def test_output_results_bad(self):
-        fmt = mock.MagicMock()
-        with mock.patch('bandit.core.extension_loader.MANAGER') as m:
-            m.formatters_mgr = {'test': fmt}
-            self.assertRaises(KeyError, self.manager.output_results,
-                3, constants.LOW, constants.LOW, None, "txt")
+    def test_run_tests_keyboardinterrupt(self):
+        # Test that bandit manager exits when there is a keyboard interrupt
+        temp_directory = self.useFixture(fixtures.TempDir()).path
+        some_file = os.path.join(temp_directory, 'some_code_file.py')
+        with open(some_file, 'wt') as fd:
+            fd.write('some_code = x + 1')
+        self.manager.files_list = [some_file]
+        with mock.patch('bandit.core.metrics.Metrics.count_issues'
+                        ) as mock_count_issues:
+            mock_count_issues.side_effect = KeyboardInterrupt
+            # assert a SystemExit with code 2
+            self.assertRaisesRegex(SystemExit, '2', self.manager.run_tests)
 
-    def test_output_results_txt(self):
-        fmt = mock.MagicMock()
-        with mock.patch('bandit.core.extension_loader.MANAGER') as m:
-            m.formatters_mgr = {'txt': fmt}
-            self.manager.output_results(3, constants.LOW, constants.LOW,
-                                        None, "test")
-            fmt.plugin.assert_called_with(self.manager, conf_level='LOW',
-                                          filename=None, lines=3,
-                                          out_format='txt', sev_level='LOW')
-
-    def test_output_results_csv(self):
-        fmt = mock.MagicMock()
-        with mock.patch('bandit.core.extension_loader.MANAGER') as m:
-            m.formatters_mgr = {'csv': fmt}
-            self.manager.output_results(3, constants.LOW, constants.LOW,
-                                        None, "csv")
-            fmt.plugin.assert_called_with(self.manager, conf_level='LOW',
-                                          filename=None, lines=1,
-                                          out_format='csv', sev_level='LOW')
-
-    def test_output_results_txt_plain(self):
-        fmt = mock.MagicMock()
-        fmt.name = 'txt'
-        with mock.patch('bandit.core.extension_loader.MANAGER') as m:
-            m.formatters_mgr = {'txt': fmt}
-            self.manager.output_results(3, constants.LOW, constants.LOW,
-                                        "dummy", "test")
-            fmt.plugin.assert_called_with(self.manager, conf_level='LOW',
-                                          filename="dummy", lines=3,
-                                          out_format='plain', sev_level='LOW')
-
-    def test_output_results_io_error(self):
-        fmt = mock.MagicMock()
-        fmt.name = 'txt'
-        fmt.plugin.side_effect = IOError
-        with mock.patch('bandit.core.extension_loader.MANAGER') as m:
-            m.formatters_mgr = {'txt': fmt}
-            self.manager.output_results(3, constants.LOW, constants.LOW,
-                                        "dummy", "test")
+    def test_run_tests_ioerror(self):
+        # Test that a file name is skipped and added to the manager.skipped
+        # list when there is an IOError attempting to open/read the file
+        temp_directory = self.useFixture(fixtures.TempDir()).path
+        no_such_file = os.path.join(temp_directory, 'no_such_file.py')
+        self.manager.files_list = [no_such_file]
+        self.manager.run_tests()
+        # since the file name and the IOError.strerror text are added to
+        # manager.skipped, we convert skipped to str to find just the file name
+        # since IOError is not constant
+        self.assertIn(no_such_file, str(self.manager.skipped))
 
     def test_compare_baseline(self):
         issue_a = self._get_issue_instance()
@@ -290,20 +256,22 @@ class ManagerTests(testtools.TestCase):
         issue_c.fname = 'file1.py'
 
         # issue c is in results, not in baseline
-        self.assertEqual([issue_c],
-                         manager._compare_baseline_results(
-                             [issue_a, issue_b],
-                             [issue_a, issue_b, issue_c]))
+        self.assertEqual(
+            [issue_c],
+            manager._compare_baseline_results([issue_a, issue_b],
+                                              [issue_a, issue_b, issue_c]))
 
         # baseline and results are the same
-        self.assertEqual([],
-                         manager._compare_baseline_results([issue_a, issue_b, issue_c],
-                                                           [issue_a, issue_b, issue_c]))
+        self.assertEqual(
+            [],
+            manager._compare_baseline_results([issue_a, issue_b, issue_c],
+                                              [issue_a, issue_b, issue_c]))
 
         # results are better than baseline
-        self.assertEqual([],
-                         manager._compare_baseline_results([issue_a, issue_b, issue_c],
-                                                           [issue_a, issue_b]))
+        self.assertEqual(
+            [],
+            manager._compare_baseline_results([issue_a, issue_b, issue_c],
+                                              [issue_a, issue_b]))
 
     def test_find_candidate_matches(self):
         issue_a = self._get_issue_instance()
@@ -314,19 +282,20 @@ class ManagerTests(testtools.TestCase):
 
         # issue a and b are the same, both should be returned as candidates
         self.assertEqual({issue_a: [issue_a, issue_b]},
-                         manager._find_candidate_matches([issue_a], [issue_a, issue_b]))
+                         manager._find_candidate_matches([issue_a],
+                                                         [issue_a, issue_b]))
 
         # issue a and c are different, only a should be returned
         self.assertEqual({issue_a: [issue_a]},
-                         manager._find_candidate_matches([issue_a], [issue_a, issue_c]))
+                         manager._find_candidate_matches([issue_a],
+                                                         [issue_a, issue_c]))
 
         # c doesn't match a, empty list should be returned
         self.assertEqual({issue_a: []},
                          manager._find_candidate_matches([issue_a], [issue_c]))
 
         # a and b match, a and b should both return a and b candidates
-        self.assertEqual({issue_a: [issue_a, issue_b],
-                          issue_b: [issue_a, issue_b]},
-
-                         manager._find_candidate_matches([issue_a, issue_b],
-                                                         [issue_a, issue_b, issue_c]))
+        self.assertEqual(
+            {issue_a: [issue_a, issue_b], issue_b: [issue_a, issue_b]},
+            manager._find_candidate_matches([issue_a, issue_b],
+                                            [issue_a, issue_b, issue_c]))
