@@ -21,10 +21,10 @@ import shutil
 import sys
 import tempfile
 
+import mock
+import six.moves.builtins as builtins
 import testtools
 
-import six
-
 from bandit.core import utils as b_utils
 
 
@@ -35,21 +35,19 @@ def _touch(path):
 
 
 class UtilTests(testtools.TestCase):
-    '''This set of tests exercises bandit.core.util functions
-    '''
+    '''This set of tests exercises bandit.core.util functions.'''
 
     def setUp(self):
         super(UtilTests, self).setUp()
         self._setup_get_module_qualname_from_path()
 
     def _setup_get_module_qualname_from_path(self):
-        '''Setup a fake module directory tree for testing
-           get_module_qualname_from_path().
+        '''Setup a fake directory for testing get_module_qualname_from_path().
 
-           Create temporary directory and then create fake .py files
-           within directory structure.  We setup test cases for
-           a typical module, a path misssing a middle __init__.py,
-           no __init__.py anywhere in path, symlinking .py files.
+        Create temporary directory and then create fake .py files
+        within directory structure.  We setup test cases for
+        a typical module, a path misssing a middle __init__.py,
+        no __init__.py anywhere in path, symlinking .py files.
         '''
 
         self.tempdir = tempfile.mkdtemp()
@@ -99,15 +97,23 @@ class UtilTests(testtools.TestCase):
                    os.path.join(self.tempdir, 'syms', 'a', 'bsym'))
 
     def test_get_module_qualname_from_path_abs_typical(self):
-        '''Test get_module_qualname_from_path with typical absolute paths'''
+        '''Test get_module_qualname_from_path with typical absolute paths.'''
 
         name = b_utils.get_module_qualname_from_path(os.path.join(
             self.tempdir, 'good', 'a', 'b', 'c', 'test_typical.py'))
         self.assertEqual('good.a.b.c.test_typical', name)
 
+    def test_get_module_qualname_from_path_with_dot(self):
+        '''Test get_module_qualname_from_path with a "." .'''
+
+        name = b_utils.get_module_qualname_from_path(os.path.join(
+            '.', '__init__.py'))
+
+        self.assertEqual('__init__', name)
+
     def test_get_module_qualname_from_path_abs_missingmid(self):
-        '''Test get_module_qualname_from_path with missing module
-           __init__.py'''
+        # Test get_module_qualname_from_path with missing module
+        # __init__.py
 
         name = b_utils.get_module_qualname_from_path(os.path.join(
             self.tempdir, 'missingmid', 'a', 'b', 'c',
@@ -115,8 +121,8 @@ class UtilTests(testtools.TestCase):
         self.assertEqual('b.c.test_missingmid', name)
 
     def test_get_module_qualname_from_path_abs_missingend(self):
-        '''Test get_module_qualname_from_path with no __init__.py
-        in last dir'''
+        # Test get_module_qualname_from_path with no __init__.py
+        # last dir'''
 
         name = b_utils.get_module_qualname_from_path(os.path.join(
             self.tempdir, 'missingend', 'a', 'b', 'c',
@@ -124,22 +130,22 @@ class UtilTests(testtools.TestCase):
         self.assertEqual('test_missingend', name)
 
     def test_get_module_qualname_from_path_abs_syms(self):
-        '''Test get_module_qualname_from_path with symlink in path'''
+        '''Test get_module_qualname_from_path with symlink in path.'''
 
         name = b_utils.get_module_qualname_from_path(os.path.join(
             self.tempdir, 'syms', 'a', 'bsym', 'c', 'test_typical.py'))
         self.assertEqual('syms.a.bsym.c.test_typical', name)
 
     def test_get_module_qualname_from_path_rel_typical(self):
-        '''Test get_module_qualname_from_path with typical relative paths'''
+        '''Test get_module_qualname_from_path with typical relative paths.'''
 
         name = b_utils.get_module_qualname_from_path(os.path.join(
             self.reltempdir, 'good', 'a', 'b', 'c', 'test_typical.py'))
         self.assertEqual('good.a.b.c.test_typical', name)
 
     def test_get_module_qualname_from_path_rel_missingmid(self):
-        '''Test get_module_qualname_from_path with module __init__.py
-           missing and relative paths'''
+        # Test get_module_qualname_from_path with module __init__.py
+        # missing and relative paths
 
         name = b_utils.get_module_qualname_from_path(os.path.join(
             self.reltempdir, 'missingmid', 'a', 'b', 'c',
@@ -147,8 +153,8 @@ class UtilTests(testtools.TestCase):
         self.assertEqual('b.c.test_missingmid', name)
 
     def test_get_module_qualname_from_path_rel_missingend(self):
-        '''Test get_module_qualname_from_path with __init__.py missing from
-           last dir and using relative paths'''
+        # Test get_module_qualname_from_path with __init__.py missing from
+        # last dir and using relative paths
 
         name = b_utils.get_module_qualname_from_path(os.path.join(
             self.reltempdir, 'missingend', 'a', 'b', 'c',
@@ -156,14 +162,14 @@ class UtilTests(testtools.TestCase):
         self.assertEqual('test_missingend', name)
 
     def test_get_module_qualname_from_path_rel_syms(self):
-        '''Test get_module_qualname_from_path with symbolic relative paths'''
+        '''Test get_module_qualname_from_path with symbolic relative paths.'''
 
         name = b_utils.get_module_qualname_from_path(os.path.join(
             self.reltempdir, 'syms', 'a', 'bsym', 'c', 'test_typical.py'))
         self.assertEqual('syms.a.bsym.c.test_typical', name)
 
     def test_get_module_qualname_from_path_sys(self):
-        '''Test get_module_qualname_from_path with system module paths'''
+        '''Test get_module_qualname_from_path with system module paths.'''
 
         name = b_utils.get_module_qualname_from_path(os.__file__)
         self.assertEqual('os', name)
@@ -173,13 +179,13 @@ class UtilTests(testtools.TestCase):
         # self.assertEqual(name, 'os.path')
 
     def test_get_module_qualname_from_path_invalid_path(self):
-        '''Test get_module_qualname_from_path with invalid path '''
+        '''Test get_module_qualname_from_path with invalid path.'''
 
         name = b_utils.get_module_qualname_from_path('/a/b/c/d/e.py')
         self.assertEqual('e', name)
 
     def test_get_module_qualname_from_path_dir(self):
-        '''Test get_module_qualname_from_path with dir path '''
+        '''Test get_module_qualname_from_path with dir path.'''
 
         self.assertRaises(b_utils.InvalidModulePath,
                           b_utils.get_module_qualname_from_path, '/tmp/')
@@ -194,13 +200,13 @@ class UtilTests(testtools.TestCase):
         self.assertEqual('name', tail)
 
     def test_get_call_name1(self):
-        '''Gets a qualified call name'''
+        '''Gets a qualified call name.'''
         tree = ast.parse('a.b.c.d(x,y)').body[0].value
         name = b_utils.get_call_name(tree, {})
         self.assertEqual('a.b.c.d', name)
 
     def test_get_call_name2(self):
-        '''Gets qualified call name and resolves aliases'''
+        '''Gets qualified call name and resolves aliases.'''
         tree = ast.parse('a.b.c.d(x,y)').body[0].value
 
         name = b_utils.get_call_name(tree, {'a': 'alias.x.y'})
@@ -213,7 +219,7 @@ class UtilTests(testtools.TestCase):
         self.assertEqual('alias.x.y', name)
 
     def test_get_call_name3(self):
-        '''Getting name for a complex call'''
+        '''Getting name for a complex call.'''
         tree = ast.parse('a.list[0](x,y)').body[0].value
         name = b_utils._get_attr_qual_name(tree, {})
         self.assertEqual('', name)
@@ -290,3 +296,34 @@ class UtilTests(testtools.TestCase):
                 self.assertEqual(b_utils.parse_ini_file(t.name),
                                  test['expected'])
 
+    @mock.patch('os.path.isdir')
+    def test_check_output_destination_dir(self, isdir):
+        isdir.return_value = True
+
+        def _b_tester(a, b):
+            with b_utils.output_file(a, b):
+                pass
+
+        self.assertRaises(RuntimeError, _b_tester, 'derp', 'r')
+
+    @mock.patch('os.path.isdir')
+    def test_check_output_destination_bad(self, isdir):
+        with mock.patch.object(builtins, 'open') as b_open:
+            isdir.return_value = False
+            b_open.side_effect = IOError()
+
+            def _b_tester(a, b):
+                with b_utils.output_file(a, b):
+                    pass
+
+            self.assertRaises(IOError, _b_tester, 'derp', 'r')
+
+    def test_check_ast_node_good(self):
+        node = b_utils.check_ast_node("Call")
+        self.assertEqual("Call", node)
+
+    def test_check_ast_node_bad_node(self):
+        self.assertRaises(TypeError, b_utils.check_ast_node, 'Derp')
+
+    def test_check_ast_node_bad_type(self):
+        self.assertRaises(TypeError, b_utils.check_ast_node, 'walk')
