@@ -14,7 +14,6 @@
 #  under the License.
 
 from collections import OrderedDict
-import os
 import tempfile
 
 from bs4 import BeautifulSoup
@@ -23,8 +22,8 @@ import testtools
 
 import bandit
 from bandit.core import config
-from bandit.core import manager
 from bandit.core import issue
+from bandit.core import manager
 from bandit.formatters import html as b_html
 
 
@@ -32,9 +31,7 @@ class HtmlFormatterTests(testtools.TestCase):
 
     def setUp(self):
         super(HtmlFormatterTests, self).setUp()
-
-        cfg_file = os.path.join(os.getcwd(), 'bandit/config/bandit.yaml')
-        conf = config.BanditConfig(cfg_file)
+        conf = config.BanditConfig()
         self.manager = manager.BanditManager(conf, 'file')
 
         (tmp_fd, self.tmp_fname) = tempfile.mkstemp()
@@ -76,7 +73,8 @@ class HtmlFormatterTests(testtools.TestCase):
 
         issue_y = _get_issue_instance()
 
-        get_issue_list.return_value = OrderedDict([(issue_a, [issue_x, issue_y]),
+        get_issue_list.return_value = OrderedDict([(issue_a, [issue_x,
+                                                              issue_y]),
                                                    (issue_b, [issue_x]),
                                                    (issue_c, [issue_y])])
 
